#!/bin/sh

echo "[INFO] Recording to /storage/capture/${EVENT}/${ROOM} started…"

mkdir -p "/storage/capture/${EVENT}"

ffmpeg -y -nostdin -hide_banner -re \
    -init_hw_device vaapi=vaapi0:/dev/dri/renderD129 \
    -hwaccel vaapi \
    -hwaccel_output_format vaapi \
    -thread_queue_size 512 -i tcp://localhost:11000?timeout=3000000 \
    -filter_hw_device vaapi0 \
    -filter_complex "[0:v]format=nv12,hwupload[hd];" \
    -c:v h264_vaapi \
    -flags +cgop -aspect 16:9 \
    -r:v:0 60 -g:v:0 180 \
    -map "[hd]" \
    -metadata:s:v:0 title="HD" \
    -map "0:a:0" -metadata:s:a:0 title="native" \
    -c:a s302m \
    -strict -2 \
    -flags +global_header \
    -f segment \
    -segment_time 180 \
    -strftime 1 \
    -segment_format mpegts \
    "/storage/capture/${EVENT}/${ROOM}-%Y-%m-%d_%H-%M-%S-$$.ts"

ffmpeg_error_code=$?
if [ "0" -ne "$ffmpeg_error_code" ]; then
   echo "[ERROR] Recording failed, ffmpeg exited $ffmpeg_error_code"
else
   echo "[WARN] Recording stopped!"
fi

exit $ffmpeg_error_code
